@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.22.1-Białowieża"
-#define _QGIS_VERSION "3.22.1-Białowieża"
+#define VERSION "3.32.2-Lima"
+#define _QGIS_VERSION "3.32.2-Lima"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3221
+//#define VERSION_INT 3322
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 32201
-#define _QGIS_VERSION_INT 32201
-#define ABISYM(x) x ## 32201
+#define VERSION_INT 33202
+#define _QGIS_VERSION_INT 33202
+#define ABISYM(x) x ## 33202
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Białowieża"
+#define RELEASE_NAME "Lima"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,12 +31,12 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.22.1"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.32.2"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
 #if !defined(QSCINTILLA_VERSION_STR)
-#define QSCINTILLA_VERSION_STR "2.13.1"
+#define QSCINTILLA_VERSION_STR "2.14.1"
 #endif
 
 #if defined( __APPLE__ )
@@ -46,10 +46,14 @@
 
 #define QT_PLUGINS_DIR "/usr/lib/qt/plugins"
 
-#define PYTHON_VERSION "3.9.7"
+#define PYTHON_VERSION "3.11.5"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "9"
-#define PYTHON_VERSION_PATCH "7"
+#define PYTHON_VERSION_MINOR "11"
+#define PYTHON_VERSION_PATCH "5"
+
+#define PROJ_VERSION_MAJOR 9
+#define PROJ_VERSION_MINOR 2
+#define PROJ_VERSION_PATCH 1
 
 /* #undef USING_NMAKE */
 
@@ -86,23 +90,33 @@
 
 /* #undef QGISDEBUG */
 
-/* #undef HAVE_QUICK */
+/* #undef AGGRESSIVE_SAFE_MODE */
 
-#define HAVE_QT5SERIALPORT
+#define HAVE_QUICK
+
+#define HAVE_QTSERIALPORT
 
 /* #undef HAVE_STATIC_PROVIDERS */
 
 #define HAVE_EPT
 
-#define HAVE_PDAL
-#define PDAL_VERSION "2.3.0"
+#define HAVE_COPC
+
+#define HAVE_PDAL_QGIS
+#define PDAL_VERSION "2.5.6"
 #define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 3
+#define PDAL_VERSION_MINOR_INT 5
 #define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "3"
-#define PDAL_VERSION_MICRO "0"
+#define PDAL_VERSION_MINOR "5"
+#define PDAL_VERSION_MICRO "6"
 
 #define ENABLE_TESTS
 
+#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
+#define HAS_KDE_QT5_SMALL_CAPS_FIX
+#define HAS_KDE_QT5_FONT_STRETCH_FIX
+
+#define HAVE_CRASH_HANDLER
+
 #endif
 
